Enum ConnectionError

#[non_exhaustive]
pub enum ConnectionError {
Show 13 variants AttemptDiscarded, Crypto(Error), CryptoInvalidLength, CryptoModeInvalid, CryptoModeUnavailable, EndpointUrl, IllegalDiscoveryResponse, IllegalIp, Io(Error), Json(Error), InterconnectFailure(Recipient), Ws(Error), TimedOut,
}
Available on crate feature driver only.
Errors encountered while connecting to a Discord voice server over the driver.

Variants (Non-exhaustive)

This enum is marked as non-exhaustive
Non-exhaustive enums could have additional variants added in future. Therefore, when matching against variants of non-exhaustive enums, an extra wildcard arm must be added to account for any future variants.


AttemptDiscarded

The driver hung up an internal signaller, either due to another connection attempt or a crash.



Crypto(Error)

An error occurred during [en/de]cryption of voice packets.



CryptoInvalidLength

The symmetric key supplied by Discord had the wrong size.



CryptoModeInvalid

Server did not return the expected crypto mode during negotiation.



CryptoModeUnavailable

Selected crypto mode was not offered by server.



EndpointUrl

An indicator that an endpoint URL was invalid.



IllegalDiscoveryResponse

Discord failed to correctly respond to IP discovery.



IllegalIp

Could not parse Discord’s view of our IP.



Io(Error)

Miscellaneous I/O error.



Json(Error)

JSON (de)serialization error.



InterconnectFailure(Recipient)

Failed to message other background tasks after connection establishment.



Ws(Error)

Error communicating with gateway server over WebSocket.



TimedOut

Connection attempt timed out.