pub enum CodecCacheError {
Create(AudioStreamError),
Parse(Error),
Opus(Error),
MetadataEncoding(JsonError),
MetadataTooLarge,
CreatePanicked,
UnknownChannelCount,
Streamcatcher(CatcherError),
StreamNotAtStart,
}Available on crate feature
driver only.Expand description
Errors encountered using a Compressed or Decompressed cached source.
Variants
Create(AudioStreamError)
The audio stream could not be created.
Parse(Error)
Symphonia failed to parse the container or decode the default stream.
Opus(Error)
The Opus encoder could not be created.
MetadataEncoding(JsonError)
The file’s metadata could not be converted to JSON.
MetadataTooLarge
The input’s metadata was too large after conversion to JSON to fit in a DCA file.
CreatePanicked
The audio stream failed to be created due to a panic in spawn_blocking.
UnknownChannelCount
The audio stream’s channel count could not be determined.
Streamcatcher(CatcherError)
Streamcatcher’s configuration was illegal, and the cache could not be created.
StreamNotAtStart
The input stream had already been read (i.e., Parsed) and so the whole stream
could not be used.