#[non_exhaustive]pub enum MakePlayableError {
Create(AudioStreamError),
Parse(Error),
Panicked,
}Available on crate feature
driver only.Expand description
Errors encountered when readying or pre-processing an Input.
Variants (Non-exhaustive)
This enum is marked as non-exhaustive
Non-exhaustive enums could have additional variants added in future. Therefore, when matching against variants of non-exhaustive enums, an extra wildcard arm must be added to account for any future variants.
Create(AudioStreamError)
Parse(Error)
Failed to read headers, codecs, or a valid stream from a LiveInput.
Panicked
A blocking thread panicked or failed to return a parsed input.