#[non_exhaustive]pub enum MetadataError {
NotLive,
NotParsed,
}Available on crate feature
driver only.Expand description
Errors encountered when trying to access in-stream Metadata for an Input.
Both cases can be solved by using Input::make_playable or LiveInput::promote.
Variants (Non-exhaustive)
This enum is marked as non-exhaustive
Non-exhaustive enums could have additional variants added in future. Therefore, when matching against variants of non-exhaustive enums, an extra wildcard arm must be added to account for any future variants.
NotLive
This input is currently lazily initialised, and must be made live.
NotParsed
This input is ready, but has not had its headers parsed.