Struct AsyncAdapterStream

pub struct AsyncAdapterStream { /* private fields */ }
Available on crate feature driver only.
An adapter for converting an async media source into a synchronous one usable by symphonia.

This adapter takes a source implementing AsyncRead, and allows the receive side to pass along seek requests needed. This allows for passing bytes from exclusively AsyncRead streams (e.g., hyper HTTP sessions) to Songbird.

Implementations

Source

impl AsyncAdapterStream

pub fn new( stream: Box<dyn AsyncMediaSource>, buf_len: usize, ) -> AsyncAdapterStream

Wrap and pull from an async file stream, with an intermediate ring-buffer of size buf_len between the async and sync halves.