pub struct HttpRequest {
pub client: Client,
pub request: String,
pub headers: HeaderMap,
pub content_length: Option<u64>,
}Available on crate feature
driver only.Expand description
A lazily instantiated HTTP request.
Fields
client: ClientA reqwest client instance used to send the HTTP GET request.
request: StringThe target URL of the required resource.
headers: HeaderMapHTTP header fields to add to any created requests.
content_length: Option<u64>Content length, used as an upper bound in range requests if known.
This is only needed for certain domains who expect to see a value like
range: bytes=0-1023 instead of the simpler range: bytes=0- (such as
Youtube).
Implementations