#[non_exhaustive]pub enum ControlError {
Finished,
InvalidTrackEvent,
Play(PlayError),
Dropped,
}Available on crate feature
driver only.Expand description
Errors associated with control and manipulation of tracks.
Unless otherwise stated, these don’t invalidate an existing track, but do advise on valid operations and commands.
Variants (Non-exhaustive)
This enum is marked as non-exhaustive
Non-exhaustive enums could have additional variants added in future. Therefore, when matching against variants of non-exhaustive enums, an extra wildcard arm must be added to account for any future variants.
Finished
The operation failed because the track has ended, has been removed due to call closure, or some error within the driver.
InvalidTrackEvent
The supplied event listener can never be fired by a track, and should be attached to the driver instead.
Play(PlayError)
A command to seek or ready the target track failed when parsing or creating the stream.
This is a fatal error, and the track will be removed.
Dropped
Another seek/make_playable request was made, and so this callback handler was dropped.